@@ -7,15 +7,12 @@
 
 from __future__ import unicode_literals
 
-from ipaddress import ip_address
 import itertools
+from ipaddress import ip_address
 
 import pytest
 import six
-from typepy import (
-    Typecode,
-    StrictLevel,
-)
+from typepy import StrictLevel, Typecode
 from typepy.type import IpAddress
 
 
@@ -32,13 +29,19 @@ class Test_IpAddress_is_type(object):
             [StrictLevel.MIN, StrictLevel.MAX],
             [False]
         )) + list(itertools.product(
-            [
-                "127.0.0.1", "::1",
-                ip_address("127.0.0.1"), ip_address("::1"),
-            ],
+            [ip_address("127.0.0.1"), ip_address("::1")],
             [StrictLevel.MIN, StrictLevel.MAX],
             [True],
-        )))
+        )) + list(itertools.product(
+            ["127.0.0.1", "::1", "800::800"],
+            [StrictLevel.MIN],
+            [True],
+        )) + list(itertools.product(
+            ["127.0.0.1", "::1", "800::800"],
+            [StrictLevel.MAX],
+            [False],
+        ))
+    )
     def test_normal(self, value, strict_level, expected):
         type_checker = IpAddress(value, strict_level=strict_level)
 
