@@ -11,10 +11,7 @@ import itertools
 
 import pytest
 import six
-from typepy import (
-    Typecode,
-    StrictLevel,
-)
+from typepy import StrictLevel, Typecode
 from typepy.type import NoneType
 
 
