@@ -8,16 +8,10 @@ from __future__ import absolute_import
 
 import typepy.type
 
+from .__version__ import __author__, __copyright__, __email__, __license__, __version__
 from ._const import StrictLevel
 from ._error import TypeConversionError
 from ._function import (
-    is_hex,
-    is_list_or_tuple,
-    is_null_string,
-    is_not_null_string,
-    is_empty_string,
-    is_not_empty_string,
-    is_empty_sequence,
-    is_not_empty_sequence,
-)
+    is_empty_sequence, is_empty_string, is_hex, is_list_or_tuple, is_not_empty_sequence,
+    is_not_empty_string, is_not_null_string, is_null_string)
 from ._typecode import Typecode
