@@ -4,8 +4,7 @@
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
 import warnings
 
@@ -21,22 +20,8 @@ def is_hex(value):
     return True
 
 
-def _is_list(value):
-    return isinstance(value, list)
-
-
-def _is_tuple(value):
-    return isinstance(value, tuple)
-
-
 def is_list_or_tuple(value):
-    """
-    .. warning::
-
-        This function will be deleted in the future.
-    """
-
-    return any([_is_list(value), _is_tuple(value)])
+    return isinstance(value, (tuple, list))
 
 
 def is_null_string(value):
