@@ -8,10 +8,7 @@ from __future__ import absolute_import
 
 from .._const import StrictLevel
 from ..type._integer import Integer
-from ._checker import (
-    TypeChecker,
-    TypeCheckerStrictLevel,
-)
+from ._checker import TypeChecker, TypeCheckerStrictLevel
 from ._common import isstring
 
 
@@ -33,10 +30,8 @@ class BoolTypeCheckerStrictLevel1(BoolTypeCheckerStrictLevel0):
 class BoolTypeCheckerStrictLevel2(BoolTypeCheckerStrictLevel1):
 
     def is_exclude_instance(self):
-        return (
-            super(BoolTypeCheckerStrictLevel2, self).is_exclude_instance() or
-            isstring(self._value)
-        )
+        return (super(BoolTypeCheckerStrictLevel2, self).is_exclude_instance() or
+                isstring(self._value))
 
 
 class BoolTypeChecker(TypeChecker):
