@@ -4,8 +4,7 @@
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
 import six
 
@@ -36,10 +35,10 @@ class BoolConverter(AbstractValueConverter):
         try:
             lower_text = value.lower()
         except AttributeError:
-            raise ValueError("invalid value '{}'".format(str(value)))
+            raise ValueError("invalid value '{}'".format(six.text_type(value)))
 
         binary_value = strtobool(lower_text)
         if lower_text not in ["true", "false"]:
-            raise ValueError("invalid value '{}'".format(str(value)))
+            raise ValueError("invalid value '{}'".format(six.text_type(value)))
 
         return bool(binary_value)
